@@ -1,5 +1,5 @@
 test_that("this crashes", {
   expect_true(TRUE)
   expect_true(FALSE)
-  asNamespace("callr")$crash()
+  rlang::node_car(0)
 })
